/**************************************************************

   Program Title:  GenY32 GRBL Port
   
   Program Name:  ser.h	 Version: 1.00
   
   Author:  ALD	  					  Date:  May 10, 2014
   
   Compiled with AVR Studio 6.1.2730
   
   This file contains routines that implement a generic interface
   in both USART serial ports and the USB CDC stack.
   
   Copyright 2014, Tony da Costa  All rights reserved.
   
****************************************************************/
/*
 * Copyright 2014, Tony da Costa  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY TONY DA COSTA AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SOC ROBOTICS, 
 * INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

/*
 * ser.h
 *
 * Created: 03/05/2014 6:13:38 PM
 *  Author: tdacosta
 */ 


#ifndef SER_H_
#define SER_H_

#include "typedefs.h"

#ifdef __cplusplus
extern "C" {
	#endif
	
	typedef int (*T_SER_CALLBACK_PTR)(uint8_t);

	#define COM_NUM 3
	#define COM1 0
	#define COM2 1
	#define COMUSB 2
	
	BOOL ser_Init(void);
	BOOL ser_SetLineParam(UINT8 comId, UINT32 baudrate, UINT8 bits, UINT8 parity, UINT8 stopBits, BOOL swHandshaking);
	BOOL ser_RegisterReceiveCallback(UINT8 comId, T_SER_CALLBACK_PTR cbPtr);

	BOOL ser_GetChar(UINT8 comId, UINT8 *ch);
	UINT16 ser_Read(UINT8 comId, UINT8 *buffer, UINT16 count);
	UINT16 ser_GetRxBufferCount(UINT8 comId);
	BOOL ser_FlushRxBuffer(UINT8 comId);

	BOOL ser_PutChar(UINT8 comId, UINT8 ch);
	BOOL ser_Write(UINT8 comId, UINT8 *buffer, UINT16 count);
	BOOL ser_SendString(UINT8 comId, char *str);
	UINT16 ser_GetTxBufferCount(UINT8 comId);
	
#ifdef __cplusplus
}
#endif


#endif /* SERIAL_H_ */